==> smart_energy_data_vald3nir-1.0.3-py3-none-any.whl: smart_energy_data/repository/__init__.py <==
from dataclasses import dataclass, asdict

from toolkit.database.mongodb.mongo_api import MongoAPI
from toolkit.database.mongodb.mongo_dao import MongoDAO

from keys.smart_energy_secrets import DatabaseEnv
from src import mongodb_address


# ----------------------------------------------------------------------------------------------------------------------
class BaseApi(MongoAPI):
    def __init__(self, collection: str, print_curl: bool = False) -> None:
        super().__init__(
            api_url=DatabaseEnv.DATABASE_API.value,
            api_key=DatabaseEnv.DATABASE_API_KEY.value,
            database=DatabaseEnv.DATABASE_NAME.value,
            data_source=DatabaseEnv.DATA_SOURCE.value,
            collection=collection,
            print_curl=print_curl
        )


# ----------------------------------------------------------------------------------------------------------------------

class BaseDAO(MongoDAO):

    def __init__(self, collection: str) -> None:
        super().__init__(
            client_url=mongodb_address(),
            project_name=DatabaseEnv.DATABASE_NAME.value,
            collection=collection,
        )

    def get_all(self) -> list[dict]:
        return self.find_documents()


# ----------------------------------------------------------------------------------------------------------------------

@dataclass
class BaseDTO:

    def to_json(self) -> dict:
        return asdict(self)

# ----------------------------------------------------------------------------------------------------------------------

==> smart_energy_data_vald3nir-1.0.11-py3-none-any.whl: smart_energy_data/repository/__init__.py <==
from dataclasses import dataclass, asdict

from toolkit.database.mongodb.mongo_api import MongoAPI
from toolkit.database.mongodb.mongo_dao import MongoDAO

from src.smart_energy_data.project import mongodb_address
from src.smart_energy_data.project.secret import DatabaseEnv


# ----------------------------------------------------------------------------------------------------------------------
class BaseApi(MongoAPI):
    def __init__(self, collection: str, print_curl: bool = False) -> None:
        super().__init__(
            api_url=DatabaseEnv.DATABASE_API.value,
            api_key=DatabaseEnv.DATABASE_API_KEY.value,
            database="smart_energy",
            data_source=DatabaseEnv.DATA_SOURCE.value,
            collection=collection,
            print_curl=print_curl
        )


# ----------------------------------------------------------------------------------------------------------------------

class BaseDAO(MongoDAO):

    def __init__(self, collection: str, database: str = "smart_energy") -> None:
        super().__init__(
            client_url=mongodb_address(),
            project_name=database,
            collection=collection,
        )

    def get_all(self) -> list[dict]:
        return self.find_documents()


# ----------------------------------------------------------------------------------------------------------------------

@dataclass
class BaseDTO:

    def to_json(self) -> dict:
        return asdict(self)

# ----------------------------------------------------------------------------------------------------------------------
